.. :changelog:

History
-------

0.2.16 (2020-11-03)
+++++++++++++++++++

* Better cache for user permissions

0.2.15 (2020-10-24)
+++++++++++++++++++

* New django-fperms library and related changes

0.2.14 (2020-10-22)
+++++++++++++++++++

* Better verbose name of default permission
* Improved sync_permissions command, unchanged permissions are not printed as updated


0.1.0 (2018-03-13)
++++++++++++++++++

* First release on PyPI.
